@@ -111,10 +111,12 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
             component = Component.objects.get(id=applicationComponent.obj.component_id)
             insertComponent = {
                 "type": component.name,
-                "route": False,
+                "route": format(component.preferred_route),
                 "parameters": [],
                 "extensions": [],
             }
+            if component.auto_import:
+                insertComponent["experimental"] = ["routing"]
             keys = []
             for parameter in applicationComponent.obj.parameters.all():
                 if parameter.key == "route":
@@ -136,9 +138,11 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
                 extension = Component.objects.get(id=extensionComponent.component_id)
                 componentExtension = {
                     "type": extension.name,
-                    "route": False,
+                    "route": format(component.preferred_route),
                     "parameters": [],
                 }
+                if extension.auto_import:
+                    componentExtension["experimental"] = ["routing"]
                 keys = []
                 for parameter in extensionComponent.parameters.all():
                     if parameter.key == "route":
